.. _about-xrt:

.. image:: images/hinode_satellite.png
   :alt: Hinode Satellite
   :align: right
   :scale: 64%


*******************************
About the X-Ray Telescope (XRT)
*******************************

.. contents:: Contents
   :local:


Hinode
======
Hinode is a joint mission involving the space agencies of Japan, the United States, Europe,  and the United Kingdom. It is depicted in the *illustration shown above*.
The spacecraft is equipped with three instruments: the Solar Optical Telescope (SOT), the Extreme Ultraviolet Imaging Spectrometer (EIS), and the X-Ray Telescope (XRT).
These instruments are designed to provide multi-wavelength data from the  photosphere to the upper corona. The solar spacecraft spacecraft was launched at 6:36 a.m on
September 23, 2006 (Japan Standard Time) and placed into a polar,  sun-synchronous orbit, enabling continuous observations of the Sun. For further information, visit `NASA's Hinode space mission to the Sun`_.



The X-Ray Telescope
====================
The X-Ray Telescope (XRT) is an instrument onboard the Hinode spacecraft. With its remarkable capabilities, the XRT provides high-resolution
images of the solar corona's hottest material, ranging from 1,000,000 to 10,000,000 Kelvin. Visit the official `xrt-cfa-harvard`_ website for mission overview information about the XRT.

.. tip::
   Visit the `XRT Picture of the Week`_ and the `Hinode-XRT YouTube`_ page for captivating visual content showcasing the XRT's solar observations.


SolarSoft XRT Analysis Guide
============================
The `SolarSoft XRT Analysis Guide`_ is a comprehensive resource for analysis of XRT data.
It includes both an Instrument Guide and an overview of the X-Ray telescope's hardware components.
The XRT software was originally created in Interactive Data Language (IDL).
IDL is a software programming language used to analyze and create meaningful information from numerical data.


.. note::
   Please note that the `SolarSoft XRT Analysis Guide`_ does not serve as a guide for using XRTpy.
   It focuses solely on the analysis of XRT data using the IDL software.


.. _NASA's Hinode space mission to the Sun: https://www.nasa.gov/mission_pages/hinode/mission.html
.. _Interactive Data Language: https://www.l3harrisgeospatial.com/Software-Technology/IDL

.. _SolarSoft XRT Analysis Guide: https://xrt.cfa.harvard.edu/resources/documents/XAG/XAG.pdf
.. _xrt-cfa-harvard: https://xrt.cfa.harvard.edu/index.php
.. _Artist's concept of the Hinode:  https://www.nasa.gov/mission_pages/sunearth/missions/mission-hinode.html

.. _Hinode-XRT YouTube: https://www.youtube.com/user/xrtpow
.. _XRT Picture of the Week: https://xrt.cfa.harvard.edu/xpow
